@@ -6,7 +6,8 @@ from logilab.common.testlib import TestCase, unittest_main
 ## template
 
 from cubicweb.devtools.testlib import AutomaticWebTest
-
+# necessary trick to avoid cw assertion error
+class AutomaticWebTest(AutomaticWebTest): pass
 
 if __name__ == '__main__':
     unittest_main()
